From 1085752d13ead6359e7a59b96bb41edec3986d88 Mon Sep 17 00:00:00 2001
From: Greg Hogan <code@greghogan.com>
Date: Tue, 19 Jan 2021 12:51:36 +0000
Subject: [PATCH 3/7] gnu: Add aws-c-cal.

* gnu/packages/c.scm (aws-c-cal): New variable.
* gnu/packages/patches/aws-c-cal-cmake-prefix.patch:
New file.
* gnu/local.mk (dist_patch_DATA): Add it.
---
 gnu/local.mk                                  |  1 +
 gnu/packages/c.scm                            | 27 +++++++++++++++++++
 .../patches/aws-c-cal-cmake-prefix.patch      | 13 +++++++++
 3 files changed, 41 insertions(+)
 create mode 100644 gnu/packages/patches/aws-c-cal-cmake-prefix.patch

diff --git a/gnu/local.mk b/gnu/local.mk
index ae5a65cfcf..f16c1ae240 100644
--- a/gnu/local.mk
+++ b/gnu/local.mk
@@ -830,6 +830,7 @@ dist_patch_DATA =						\
   %D%/packages/patches/avahi-localstatedir.patch		\
   %D%/packages/patches/avidemux-install-to-lib.patch		\
   %D%/packages/patches/awesome-reproducible-png.patch		\
+  %D%/packages/patches/aws-c-cal-cmake-prefix.patch		\
   %D%/packages/patches/aws-c-event-stream-cmake-prefix.patch  \
   %D%/packages/patches/aws-checksums-cmake-prefix.patch		\
   %D%/packages/patches/azr3.patch				\
diff --git a/gnu/packages/c.scm b/gnu/packages/c.scm
index 7230972a68..48230b41c3 100644
--- a/gnu/packages/c.scm
+++ b/gnu/packages/c.scm
@@ -52,6 +52,7 @@
   #:use-module (gnu packages autotools)
   #:use-module (gnu packages gettext)
   #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages tls)
   #:use-module (gnu packages xml))
 
 (define-public tcc
@@ -614,3 +615,29 @@ event stream encoding, a binary format for bidirectional client-server
 communication.")
     (home-page "https://github.com/awslabs/aws-c-event-stream")
     (license license:asl2.0)))
+
+(define-public aws-c-cal
+  (package
+    (name "aws-c-cal")
+    (version "0.4.5")
+    (source (origin
+              (method git-fetch)
+              (uri (git-reference
+                    (url (string-append "https://github.com/awslabs/" name))
+                    (commit (string-append "v" version))))
+              (file-name (git-file-name name version))
+              (sha256
+               (base32
+                "04acra1mnzw9q7jycs5966akfbgnx96hkrq90nq0dhw8pvarlyv6"))
+              (patches (search-patches "aws-c-cal-cmake-prefix.patch"))))
+    (build-system cmake-build-system)
+    (propagated-inputs
+     `(("aws-c-common" ,aws-c-common)))
+    (inputs
+     `(("openssl" ,openssl)
+       ("openssl:static" ,openssl "static")))
+    (synopsis "Amazon Web Services Crypto Abstraction Layer")
+    (description "This library provides a C99 wrapper for hash, HMAC, and ECC
+cryptographic primitives for the @acronym{AWS,Amazon Web Services} SDK.")
+    (home-page "https://github.com/awslabs/aws-c-cal")
+    (license license:asl2.0)))
diff --git a/gnu/packages/patches/aws-c-cal-cmake-prefix.patch b/gnu/packages/patches/aws-c-cal-cmake-prefix.patch
new file mode 100644
index 0000000000..1ee7aa851d
--- /dev/null
+++ b/gnu/packages/patches/aws-c-cal-cmake-prefix.patch
@@ -0,0 +1,13 @@
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -10,6 +10,10 @@ endif()
+ 
+ option(BYO_CRYPTO "Set this if you want to provide your own cryptography implementation. This will cause the defaults to not be compiled." OFF)
+ 
++if (DEFINED ENV{CMAKE_PREFIX_PATH})
++    set(CMAKE_PREFIX_PATH $ENV{CMAKE_PREFIX_PATH})
++endif()
++
+ if (DEFINED CMAKE_PREFIX_PATH)
+     file(TO_CMAKE_PATH "${CMAKE_PREFIX_PATH}" CMAKE_PREFIX_PATH)
+ endif()
-- 
2.30.1

